@@ -7,4 +7,6 @@
 * License: BSD 2-Clause
 ********************************************************************************
 '''
+def version():
+    return '1.2.0'
 
